Magnetic Fields
===============

Objects for creating magnetic field objects, along with some common components.

Overview
--------

.. currentmodule:: pylcp

.. autosummary::

    magField
    constantMagneticField
    quadrupoleMagneticField
    iPMagneticField

Details
-------

  .. autoclass:: pylcp.magField
    :members:

  .. autoclass:: pylcp.constantMagneticField
    :members:

  .. autoclass:: pylcp.quadrupoleMagneticField
    :members:

  .. autoclass:: pylcp.iPMagneticField
    :members:
